==> igniteui-react-charts-16.6.8.tgz: package/ES5/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ (function (_super) {
    tslib_1.__extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.bz == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.bz.count; d++) {
            var e = Math.abs(a.op[d]) + a.oo[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.op[d] / e * 100);
            c = Math.max(c, a.oo[d] / e * 100);
        }
        a.o5 = b;
        a.o4 = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ (function (_super) {
    tslib_1.__extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.bz == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.bz.count; d++) {
            var e = Math.abs(a.ow[d]) + a.ov[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.ow[d] / e * 100);
            c = Math.max(c, a.ov[d] / e * 100);
        }
        a.pc = b;
        a.pb = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };
